==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/hu.js <==
/**
 * Hungarian
 */

$.Editable.LANGS['hu'] = {
  translation: {
    "Bold": "F\u00e9lk\u00f6v\u00e9r",
    "Italic": "D\u0151lt",
    "Underline": "Al\u00e1h\u00fazott",
    "Strikethrough": "\u00c1th\u00fazott",
    "Font Size": "Bet\u0171m\u00e9retek",
    "Color": "Sz\u00edne",
    "Background Color": "H\u00e1tt\u00e9r sz\u00edn",
    "Text Color": "Sz\u00f6veg sz\u00edne",
    "Format Block": "Form\u00e1tumok",
    "Normal": "Norm\u00e1l",
    "Paragraph": "Bekezd\u00e9s",
    "Code": "K\u00f3d",
    "Quote": "Id\u00e9zetblokk",
    "Heading 1": "C\u00edmsor 1",
    "Heading 2": "C\u00edmsor 2",
    "Heading 3": "C\u00edmsor 3",
    "Heading 4": "C\u00edmsor 4",
    "Heading 5": "C\u00edmsor 5",
    "Heading 6": "C\u00edmsor 6",
    "Alignment": "Igaz\u00edt\u00e1s",
    "Align Left": "Balra igaz\u00edt",
    "Align Center": "K\u00f6z\u00e9pre z\u00e1r",
    "Align Right": "Jobbra igaz\u00edt",
    "Justify": "Sorkiz\u00e1r\u00e1s",
    "Numbered List": "Sz\u00e1moz\u00e1s",
    "Bulleted List": "Felsorol\u00e1s",
    "Indent Less": "Beh\u00faz\u00e1s cs\u00f6kkent\u00e9se",
    "Indent More": "Beh\u00faz\u00e1s n\u00f6vel\u00e9se",
    "Select All": "Minden kijel\u00f6l\u00e9se",
    "Insert Link": "Link beilleszt\u00e9se",
    "Insert Image": "K\u00e9p besz\u00far\u00e1sa",
    "Insert Video": "Vide\u00f3 beilleszt\u00e9se",
    "Undo": "Visszavon\u00e1s",
    "Redo": "Ism\u00e9t",
    "Show HTML": "Megjelen\u00edt\u00e9se HTML",
    "Float Left": "Bal",
    "Float None": "Nincs",
    "Float Right": "Jobb",
    "Replace Image": "K\u00e9pek cser\u00e9je",
    "Remove Image": "K\u00e9p elt\u00e1vol\u00edt\u00e1sa",
    "Title": "C\u00edm",
    "Insert image": "K\u00e9p besz\u00far\u00e1sa",
    "Drop image": "Dobd k\u00e9p",
    "or click": "vagy kattintson",
    "Enter URL": "URL megad\u00e1sa",
    "Please wait!": "K\u00e9rem v\u00e1rjon!",
    "Are you sure? Image will be deleted.": "Biztos vagy benne? K\u00e9p t\u00f6rl\u00e9sre ker\u00fcl.",
    "UNLINK": "Hivatkoz\u00e1s t\u00f6rl\u00e9se",
    "Open in new tab": "Megnyit\u00e1s \u00faj lapon",
    "Type something": "T\u00edpus valami",
    "Cancel": "M\u00e9gse",
    "OK": "Rendben",
    "Manage images": "K\u00e9pek kezel\u00e9se",
    "Delete": "T\u00f6r\u00f6l",
    "Font Family": "Bet\u0171t\u00edpus",
    "Insert Horizontal Line": "Helyezze v\u00edzszintes vonal"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.4.tar.gz: django-froala-editor-0.8.4/froala_editor/static/froala_editor/js/langs/hu.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Hungarian
 */

$.Editable.LANGS['hu'] = {
  translation: {
    "Bold": "F\u00e9lk\u00f6v\u00e9r",
    "Italic": "D\u0151lt",
    "Underline": "Al\u00e1h\u00fazott",
    "Strikethrough": "\u00c1th\u00fazott",
    "Font Size": "Bet\u0171m\u00e9retek",
    "Color": "Sz\u00edne",
    "Background Color": "H\u00e1tt\u00e9r sz\u00edn",
    "Text Color": "Sz\u00f6veg sz\u00edne",
    "Format Block": "Form\u00e1tumok",
    "Normal": "Norm\u00e1l",
    "Paragraph": "Bekezd\u00e9s",
    "Code": "K\u00f3d",
    "Quote": "Id\u00e9zetblokk",
    "Heading 1": "C\u00edmsor 1",
    "Heading 2": "C\u00edmsor 2",
    "Heading 3": "C\u00edmsor 3",
    "Heading 4": "C\u00edmsor 4",
    "Heading 5": "C\u00edmsor 5",
    "Heading 6": "C\u00edmsor 6",
    "Alignment": "Igaz\u00edt\u00e1s",
    "Align Left": "Balra igaz\u00edt",
    "Align Center": "K\u00f6z\u00e9pre z\u00e1r",
    "Align Right": "Jobbra igaz\u00edt",
    "Justify": "Sorkiz\u00e1r\u00e1s",
    "Numbered List": "Sz\u00e1moz\u00e1s",
    "Bulleted List": "Felsorol\u00e1s",
    "Indent Less": "Beh\u00faz\u00e1s cs\u00f6kkent\u00e9se",
    "Indent More": "Beh\u00faz\u00e1s n\u00f6vel\u00e9se",
    "Select All": "Minden kijel\u00f6l\u00e9se",
    "Insert Link": "Link beilleszt\u00e9se",
    "Insert Image": "K\u00e9p besz\u00far\u00e1sa",
    "Insert Video": "Vide\u00f3 beilleszt\u00e9se",
    "Undo": "Visszavon\u00e1s",
    "Redo": "Ism\u00e9t",
    "Show HTML": "Megjelen\u00edt\u00e9se HTML",
    "Float Left": "Bal",
    "Float None": "Nincs",
    "Float Right": "Jobb",
    "Replace Image": "K\u00e9pek cser\u00e9je",
    "Remove Image": "K\u00e9p elt\u00e1vol\u00edt\u00e1sa",
    "Title": "C\u00edm",
    "Insert image": "K\u00e9p besz\u00far\u00e1sa",
    "Drop image": "Dobd k\u00e9p",
    "or click": "vagy kattintson",
    "Enter URL": "URL megad\u00e1sa",
    "Please wait!": "K\u00e9rem v\u00e1rjon!",
    "Are you sure? Image will be deleted.": "Biztos vagy benne? K\u00e9p t\u00f6rl\u00e9sre ker\u00fcl.",
    "UNLINK": "Hivatkoz\u00e1s t\u00f6rl\u00e9se",
    "Open in new tab": "Megnyit\u00e1s \u00faj lapon",
    "Type something": "T\u00edpus valami",
    "Cancel": "M\u00e9gse",
    "OK": "Rendben",
    "Manage images": "K\u00e9pek kezel\u00e9se",
    "Delete": "T\u00f6r\u00f6l",
    "Font Family": "Bet\u0171t\u00edpus",
    "Insert Horizontal Line": "Helyezze v\u00edzszintes vonal",
    "Table": "T\u00e1bl\u00e1zat",
    "Insert table": "T\u00e1bl\u00e1zat beilleszt\u00e9se",
    "Cell": "Cella",
    "Row": "Sor",
    "Column": "Oszlop",
    "Delete table": "T\u00e1bl\u00e1zat t\u00f6rl\u00e9se",
    "Insert cell before": "Cella besz\u00far\u00e1sa el\u00e9",
    "Insert cell after": "Cella besz\u00far\u00e1sa m\u00f6g\u00e9",
    "Delete cell": "Cella t\u00f6rl\u00e9se",
    "Merge cells": "Cell\u00e1k egyes\u00edt\u00e9se",
    "Horizontal split": "V\u00edzszintes osztott",
    "Vertical split": "F\u00fcgg\u0151leges osztott",
    "Insert row above": "Sor besz\u00far\u00e1sa el\u00e9",
    "Insert row below": "Sor besz\u00far\u00e1sa m\u00f6g\u00e9",
    "Delete row": "Sor t\u00f6rl\u00e9se",
    "Insert column before": "Oszlop besz\u00far\u00e1sa el\u00e9",
    "Insert column after": "Oszlop besz\u00far\u00e1sa m\u00f6g\u00e9",
    "Delete column": "Oszlop t\u00f6rl\u00e9se"
  },
  direction: "ltr"
};
